==> ginkgo-hpc-docs-1.9.0-3-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/classes_14.js <==
var searchData=
[
  ['value_5flist_0',['value_list',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['value_5flist_3c_20int_20_3e_1',['value_list&lt; int &gt;',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['value_5flist_3c_20t_2c_20values_2e_2e_2e_20_3e_2',['value_list&lt; T, Values... &gt;',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['value_5flist_3c_20t_2c_20values1_2e_2e_2e_2c_20values2_2e_2e_2e_20_3e_3',['value_list&lt; T, Values1..., Values2... &gt;',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['valuemismatch_4',['ValueMismatch',['../classgko_1_1ValueMismatch.html',1,'gko']]],
  ['vector_5',['Vector',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['vector_3c_20previous_5fprecision_5fbase_3c_20valuetype_20_3e_20_3e_6',['Vector&lt; previous_precision_base&lt; ValueType &gt; &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['vector_3c_20to_5fcomplex_3c_20value_5ftype_20_3e_20_3e_7',['Vector&lt; to_complex&lt; value_type &gt; &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['vector_3c_20valuetype_20_3e_8',['Vector&lt; ValueType &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['version_9',['version',['../structgko_1_1version.html',1,'gko']]],
  ['version_5finfo_10',['version_info',['../classgko_1_1version__info.html',1,'gko']]]
];

==> ginkgo-hpc-docs-1.10.0-1-x86_64.pkg.tar.zst: usr/share/doc/ginkgo-hpc/html/search/classes_14.js <==
var searchData=
[
  ['value_5flist_0',['value_list',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['value_5flist_3c_20int_20_3e_1',['value_list&lt; int &gt;',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['value_5flist_3c_20t_2c_20values_2e_2e_2e_20_3e_2',['value_list&lt; T, Values... &gt;',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['value_5flist_3c_20t_2c_20values1_2e_2e_2e_2c_20values2_2e_2e_2e_20_3e_3',['value_list&lt; T, Values1..., Values2... &gt;',['../structgko_1_1syn_1_1value__list.html',1,'gko::syn']]],
  ['valuemismatch_4',['ValueMismatch',['../classgko_1_1ValueMismatch.html',1,'gko']]],
  ['vector_5',['Vector',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['vector_3c_20previous_5fprecision_3c_20valuetype_20_3e_20_3e_6',['Vector&lt; previous_precision&lt; ValueType &gt; &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['vector_3c_20to_5fcomplex_3c_20value_5ftype_20_3e_20_3e_7',['Vector&lt; to_complex&lt; value_type &gt; &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['vector_3c_20valuetype_20_3e_8',['Vector&lt; ValueType &gt;',['../classgko_1_1experimental_1_1distributed_1_1Vector.html',1,'gko::experimental::distributed']]],
  ['version_9',['version',['../structgko_1_1version.html',1,'gko']]],
  ['version_5finfo_10',['version_info',['../classgko_1_1version__info.html',1,'gko']]]
];
